/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Automation, New Tasks, and Inequality, By Daron Acemoglu and Pascual Restrepo
Created 11/30/2019
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

if missing("`project'") {
	global project ~/Dropbox/RA_Pascual/Replication/Acemoglu_Restrepo_SBTC_PP
}

***Prepare xwalk from in1990 to consolidated BEA***
use consolidated_bea ind1990 using "${project}/xwalks/industry_xwalk_census_bea.dta" if ind1990!=., clear
unique ind1990

tempfile xw_bea
save `xw_bea'

qui {

***Clean Census Data***
foreach year in 1950 1990 2014  {

if `year'!=2014{
use ${project}/raw_data/ipums_census.dta if (year ==`year'), clear
}
else if `year'==2014{
use ${project}/raw_data/ipums_census.dta if (year==2016) & (multyear!=.) , clear
}

***Map industries to consolidated set of industries that I can track in BEA/BLS***
drop if ind1990>=900
drop if ind1990==412 /*postmail*/
drop if ind1990==873 /*unions*/
drop if ind1990==0
drop if ind1990==301 /*residual category*/
drop if ind1990==392 /*residual category*/
merge m:1 ind1990 using `xw_bea', assert(2 3) keep(3) nogen

***Generates measures of SBTC for industry***

* step 1: keep only salaried workers who report working some weeks last year*
keep if (age>=16) & (age<=64) & (empstat==1) & (classwkrd==22 | classwkrd==23 ) & (wkswork!=0)

* step 2: skill groups *
gen group_highschool	= (educd<=64)
gen group_college		= (educd>=100 & educd<=116)
gen group_somecollege	= (educd>64 & educd<100)

* step 3: hours and wages *
gen wkswork=.
replace wkswork=7 		if wkswork2==1 
replace wkswork=20 		if wkswork2==2 
replace wkswork=33 		if wkswork2==3 
replace wkswork=43.5 	if wkswork2==4 
replace wkswork=48.5 	if wkswork2==5 
replace wkswork=51 		if wkswork2==6 
assert wkswork!=.

if (`year'>=1980){
gen hrswork=uhrswork
}
else if (`year'<=1970){
gen hrswork=.
replace hrswork=7.5  if hrswork2==1 
replace hrswork=22   if hrswork2==2 
replace hrswork=32   if hrswork2==3 
replace hrswork=37   if hrswork2==4 
replace hrswork=40   if hrswork2==5 
replace hrswork=44.5 if hrswork2==6 
replace hrswork=54   if hrswork2==7 
replace hrswork=70   if hrswork2==8 
}


**Sample of wage earners (wages gathered for people who had a job in last 12 months/last year---workedyr==3)**
replace incwage=. if (incwage==0) | (incwage==999999)

*Top-coding: set to 1.5 times top code and convert to 2007 dollars *
*Convert to 2007 dollars using PCE from From BEA*
*1949: 14.110 (for 1950 census) 
*1969: 22.325 (for 1970 census)
*1989: 64.641 (for 1990 census) 
*1999: 81.110 (for 2000 census)
*2007: 97.102 (for 2006-2008 ACS)
*2010: 101.653 (for 2009-2011 ACS)	
*2014: 109.157 (for 2012-2016 ACS)

if `year'==1950{
*Note: this survey includes the years 1949, so we use the PCE in 1949*
assert incwage<=10000 if incwage!=.
replace incwage=1.5*10000 if incwage>=10000
gen real_income=incwage*(97.102/14.11)
gen MAXWG=(1.5*10000/(35*50))*(97.102/14.11)  /*Roughly 60 dollars per hour in 2007*/
}
else if `year'==1970{
*Note: this survey includes the years 1969, so we use the PCE in 1969*
assert incwage<=50000 if incwage!=.
replace incwage=1.5*50000 if incwage>=50000
gen real_income=incwage*(97.102/22.325)
gen MAXWG=(1.5*50000/(35*50))*(97.102/22.325)  /*Roughly 180 dollars per hour in 2007*/
}
else if `year'==1980{
*Note: this survey includes wages for 1979, so we use the PCE in 1989*
assert incwage<=75000 if incwage!=.
replace incwage=1.5*75000 if incwage>=75000
gen real_income=incwage*(97.102/39.531)
gen MAXWG=(1.5*75000/(35*50))*(97.102/39.531) /*Roughly 160 dollars per hour in 2007---this year generates some issues for top tail*/
}
else if `year'==1990{
*Note: this survey includes wages for 1989, so we use the PCE in 1989*
replace incwage=1.5*140000 if incwage>=140000
gen real_income=incwage*(97.102/64.641)
gen MAXWG=(1.5*140000/(35*50))*(97.102/64.641) /*Roughly 180 dollars per hour in 2007*/
}
else if `year'==2000{
*Note: this survey includes wages for 1999, so we use the PCE in 1999*
assert incwage<=175000 if incwage!=.
replace incwage=1.5*175000 if incwage>=175000
gen real_income=incwage*(97.102/81.110)
gen MAXWG=(1.5*175000/(35*50))*(97.102/81.110) /*Roughly 180 dollars in 2007*/
}
else if `year'==2008{
*Note: this survey includes the years 2006-2008, so we use the PCE in 2007*
replace incwage=1.5*210000 if incwage>=210000 
gen real_income=incwage
gen MAXWG=(1.5*210000/(35*50)) /*For all ACS years, windsorize at 180 dollars per hour*/
}
else if `year'==2011{
*Note: this survey includes the years 2009-2011, so we use the PCE in 2010*
replace incwage=1.5*210000 if incwage>=210000 
gen real_income=incwage*(97.102/101.653)
gen MAXWG=(1.5*210000/(35*50)) /*For all ACS years, windsorize at 180 dollars per hour*/
}
else if `year'==2014{
*Note: this survey includes the years 2012-2016, so we use the PCE in 2014*
replace incwage=1.5*210000 if incwage>=210000 
gen real_income=incwage*(97.102/109.157)
gen MAXWG=(1.5*210000/(35*50)) /*For all ACS years, windsorize at 180 dollars per hour*/
}

**Windsorize real hourly wages at 2 dollars (2007 dollars) below and MAXWG above (roughly 180 dollars from 2007)**
gen hrwage=real_income/(hrswork*wkswork)
replace hrwage=MAXWG if (hrwage>MAXWG) & (hrwage!=.)
replace hrwage=2 if (hrwage<2) & (hrwage!=.)

*Weekly and yearly wages*
gen wkwage=hrwage*hrswork
gen yrwage=hrwage*hrswork*wkswork

* employment (heads) *
gen heads_highschool =group_highschool
gen heads_college    =group_college
gen heads_somecollege=group_somecollege

* weeks of work *
gen weeks_highschool =group_highschool*wkswork
gen weeks_college    =group_college*wkswork
gen weeks_somecollege=group_somecollege*wkswork

* hours of work *
gen hours_highschool =group_highschool*wkswork*hrswork
gen hours_college    =group_college*wkswork*hrswork
gen hours_somecollege=group_somecollege*wkswork*hrswork

* wages *
gen wbill_highschool =group_highschool*wkswork*hrswork*hrwage
gen wbill_college    =group_college*wkswork*hrswork*hrwage
gen wbill_somecollege=group_somecollege*wkswork*hrswork*hrwage

* step 5: variables by gender *
foreach var of varlist heads_* weeks_* hours_* wbill* {
gen `var'_male  =`var'*(sex==1)
gen `var'_female=`var'*(sex==2)

gen `var'_pmale  =`var'*(sex==1)*(age>=25 & age<=54)
gen `var'_pfemale=`var'*(sex==2)*(age>=25 & age<=54)


gen `var'_a25_34  =`var'*(age>=16 & age<=34)
gen `var'_a25_39  =`var'*(age>=25 & age<=39)
gen `var'_a25_44  =`var'*(age>=25 & age<=44)
gen `var'_a25_54  =`var'*(age>=25 & age<=54)
gen `var'_a35_64  =`var'*(age>=35 & age<=64)
gen `var'_a40_64  =`var'*(age>=40 & age<=64)
gen `var'_a45_64  =`var'*(age>=45 & age<=64)


}

* step 6: conditional variables *

* conditional wages *
foreach var in hrwage wkwage yrwage{
gen `var'_highschool=`var' 	if group_highschool
gen `var'_college=`var' 	if group_college
gen `var'_somecollege=`var' if group_somecollege
}

*conditional hours*
gen hours_highschool_earners =group_highschool	*wkswork*hrswork if hrwage!=.
gen hours_college_earners    =group_college		*wkswork*hrswork if hrwage!=.
gen hours_somecollege_earners=group_somecollege	*wkswork*hrswork if hrwage!=.

*conditional counts*
gen heads_highschool_earners =group_highschool 	if hrwage!=.
gen heads_college_earners    =group_college 	if hrwage!=.
gen heads_somecollege_earners=group_somecollege	if hrwage!=.

*conditional weeks*
gen weeks_highschool_earners =group_highschool	*wkswork 	if hrwage!=.
gen weeks_college_earners    =group_college		*wkswork 	if hrwage!=.
gen weeks_somecollege_earners=group_somecollege	*wkswork	if hrwage!=.

* employment *
gen employment=1

* distributions *
qui sum hrwage_college [w=perwt*wkswork*hrswork]
local college=round(r(mean),.01)
qui sum hrwage_somecollege [w=perwt*wkswork*hrswork]
local some=round(r(mean),.01)
qui sum hrwage_highschool [w=perwt*wkswork*hrswork]
local highschool=round(r(mean),.01)


* industry level dataset *
tempfile census
save `census'

gcollapse (mean) yrwage_*  wkwage_* hrwage_* (sum) employment heads_* weeks_* hours_* wbill* [iw=perw], by(consolidated_bea)

foreach var of varlist yrwage_* wkwage_* hrwage_* employment heads_* weeks_* hours_* wbill* {
rename `var' `var'_`year'
}
save ${project}/clean_data/industry_sbtc_`year', replace

}
}
gr close
